@@ -1,17 +1,17 @@
-/* 
+/*
  * This file is part of SharedArray.
  * Copyright (C) 2014-2017 Mathieu Mirmont <mat@parad0x.org>
- * 
+ *
  * SharedArray is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * SharedArray is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with SharedArray.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -46,7 +46,7 @@ extern PyTypeObject PyArrayDescObject_Type;
 
 /* Main functions */
 extern PyObject *shared_array_create(PyObject *self, PyObject *args, PyObject *kwds);
-extern PyObject *shared_array_attach(PyObject *self, PyObject *args);
+extern PyObject *shared_array_attach(PyObject *self, PyObject *args, PyObject *kwds);
 extern PyObject *shared_array_delete(PyObject *self, PyObject *args);
 
 /* SHM list function */
